@@ -39,21 +39,21 @@ except ImportError:
     import collections
 
 
-class Score(collections.namedtuple("Score", ["cp", "mate"])):
-    """A centipawns or mate score sent by an UCI engine."""
-    pass
+class Score(collections.namedtuple("Score", "cp mate")):
+    """A *cp* (centipawns) or *mate* score sent by an UCI engine."""
+    __slots__ = ()
 
 
-class BestMove(collections.namedtuple("BestMove", ["bestmove", "ponder"])):
-    """A bestmove and ponder move sent by an UCI engine."""
-    pass
+class BestMove(collections.namedtuple("BestMove", "bestmove ponder")):
+    """A *bestmove* and *ponder* move sent by an UCI engine."""
+    __slots__ = ()
 
 
 class InfoHandler(object):
     """
     Chess engines may send information about their calculations with the
-    *info* command. Info handlers can be used to aggregate or react to this
-    information.
+    *info* command. An :class:`~chess.uci.InfoHandler` instance can be used
+    to aggregate or react to this information.
 
     >>> # Register a standard info handler.
     >>> info_handler = chess.uci.InfoHandler()
@@ -72,14 +72,14 @@ class InfoHandler(object):
     See :attr:`~chess.uci.InfoHandler.info` for a way to access this dictionary
     in a thread-safe way during search.
 
-    If you want to be notified whenever new information is available
-    you would usually subclass the *InfoHandler* class:
+    If you want to be notified whenever new information is available,
+    you would usually subclass the :class:`~chess.uci.InfoHandler` class:
 
     >>> class MyHandler(chess.uci.InfoHandler):
     ...     def post_info(self):
-    ...         # Called whenever a complete *info* line has been processed.
+    ...         # Called whenever a complete info line has been processed.
     ...         print(self.info)
-    ...         super(MyHandler, self).post_info() # release lock
+    ...         super(MyHandler, self).post_info()  # Release the lock
     """
     def __init__(self):
         self.lock = threading.Lock()
@@ -110,33 +110,33 @@ class InfoHandler(object):
         """
         Received the principal variation as a list of moves.
 
-        In MultiPV mode this is related to the most recent *multipv* number
+        In *MultiPV* mode, this is related to the most recent *multipv* number
         sent by the engine.
         """
         self.info["pv"][self.info.get("multipv", 1)] = moves
 
     def multipv(self, num):
         """
-        Received a new multipv number, starting at 1.
+        Received a new *multipv* number, starting at 1.
 
-        If multipv occurs in an info line, this is guaranteed to be called
+        If *multipv* occurs in an *info* line, this is guaranteed to be called
         before *score* or *pv*.
         """
         self.info["multipv"] = num
 
     def score(self, cp, mate, lowerbound, upperbound):
         """
-        Received a new evaluation in centipawns or a mate score.
+        Received a new evaluation in *cp* (centipawns) or a *mate* score.
 
-        *cp* may be *None* if no score in centipawns is available.
+        *cp* may be ``None`` if no score in centipawns is available.
 
-        *mate* may be *None* if no forced mate has been found. A negative
-        numbers means the engine thinks it will get mated.
+        *mate* may be ``None`` if no forced mate has been found. A negative
+        number means the engine thinks it will get mated.
 
-        lowerbound and upperbound are usually *False*. If *True*, the sent
-        score are just a lowerbound or upperbound.
+        *lowerbound* and *upperbound* are usually ``False``. If ``True``,
+        the sent score is just a *lowerbound* or *upperbound*.
 
-        In MultiPV mode this is related to the most recent *multipv* number
+        In MultiPV mode, this is related to the most recent *multipv* number
         sent by the engine.
         """
         if not lowerbound and not upperbound:
@@ -146,20 +146,20 @@ class InfoHandler(object):
         """
         Received a move the engine is currently thinking about.
 
-        These moves come directly from the engine. So the castling move
-        representation depends on the UCI_Chess960 option of the engine.
+        These moves come directly from the engine, so the castling move
+        representation depends on the *UCI_Chess960* option of the engine.
         """
         self.info["currmove"] = move
 
     def currmovenumber(self, x):
-        """Received a new currmovenumber."""
+        """Received a new current move number."""
         self.info["currmovenumber"] = x
 
     def hashfull(self, x):
         """
         Received new information about the hashtable.
 
-        The hashtable is x permill full.
+        The hashtable is *x* permill full.
         """
         self.info["hashfull"] = x
 
@@ -168,7 +168,7 @@ class InfoHandler(object):
         self.info["nps"] = x
 
     def tbhits(self, x):
-        """Received new information about the number of table base hits."""
+        """Received new information about the number of tablebase hits."""
         self.info["tbhits"] = x
 
     def cpuload(self, x):
@@ -184,7 +184,7 @@ class InfoHandler(object):
         Received a new refutation of a move.
 
         *refuted_by* may be a list of moves representing the mainline of the
-        refutation or *None* if no refutation has been found.
+        refutation or ``None`` if no refutation has been found.
 
         Engines should only send refutations if the *UCI_ShowRefutations*
         option has been enabled.
@@ -195,17 +195,17 @@ class InfoHandler(object):
         """
         Received a new snapshot of a line a specific CPU is calculating.
 
-        *cpunr* is an integer representing a specific CPU. *moves* is a list
+        *cpunr* is an integer representing a specific CPU and *moves* is a list
         of moves.
         """
         self.info["currline"][cpunr] = moves
 
     def pre_info(self, line):
         """
-        Received a new info line about to be processed.
+        Received a new info line to be processed.
 
-        When subclassing remember to call this method of the parent class in
-        order to keep the locking in tact.
+        When subclassing, remember to call this method on the parent class
+        to keep the locking intact.
         """
         self.lock.acquire()
         self.info.pop("multipv", None)
@@ -214,20 +214,20 @@ class InfoHandler(object):
         """
         Processing of a new info line has been finished.
 
-        When subclassing remember to call this method of the parent class in
-        order to keep the locking in tact.
+        When subclassing, remember to call this method on the parent class
+        to keep the locking intact.
         """
         self.lock.release()
 
     def on_bestmove(self, bestmove, ponder):
-        """A new bestmove and pondermove have been received."""
+        """A new *bestmove* and *ponder* move have been received."""
         pass
 
     def on_go(self):
         """
-        A go command is being sent.
+        A *go* command is being sent.
 
-        Since information about the previous search is invalidated the
+        Since information about the previous search is invalidated, the
         dictionary with the current information will be cleared.
         """
         with self.lock:
@@ -374,7 +374,7 @@ class Engine(object):
 
         self.ponder = None
         if self.bestmove is not None and len(tokens) >= 3 and tokens[1] == "ponder" and tokens[2] != "(none)":
-            # The ponder move must be legal after the bestmove. Generally we
+            # The ponder move must be legal after the bestmove. Generally, we
             # trust the engine on this. But we still have to convert
             # non-UCI_Chess960 castling moves.
             try:
@@ -691,8 +691,8 @@ class Engine(object):
         """
         Switch the debug mode on or off.
 
-        In debug mode the engine should send additional infos to the GUI to
-        help debugging. This mode should be switched off by default.
+        In debug mode, the engine should send additional information to the
+        GUI to help with the debugging. Usually, this mode is off by default.
 
         :param on: bool
 
@@ -729,7 +729,7 @@ class Engine(object):
 
     def setoption(self, options, async_callback=None):
         """
-        Set values for the engines available options.
+        Set values for the engine's available options.
 
         :param options: A dictionary with option names as keys.
 
@@ -778,7 +778,7 @@ class Engine(object):
 
         This can be a new game the engine should play or if the engine should
         analyse a position from a different game. Using this command is
-        recommended but not required.
+        recommended, but not required.
 
         :return: Nothing
         """
@@ -808,7 +808,7 @@ class Engine(object):
         up to the position will be sent, so that the engine can detect
         repetitions.
 
-        If the position is from a new game it is recommended to use the
+        If the position is from a new game, it is recommended to use the
         *ucinewgame* command before the *position* command.
 
         :param board: A *chess.Board*.
@@ -854,7 +854,7 @@ class Engine(object):
                 while switchyard:
                     board.push(switchyard.pop())
 
-        # Send startposition.
+        # Send starting position.
         if uci_variant == "chess" and board.fen() == chess.STARTING_FEN:
             builder.append("startpos")
         else:
@@ -889,14 +889,14 @@ class Engine(object):
         *depth*, *nodes*, *mate*, *infinite* or some time control settings,
         so that the engine knows how long to calculate.
 
-        Note that when using *infinite* or *ponder* the engine will not stop
+        Note that when using *infinite* or *ponder*, the engine will not stop
         until it is told to.
 
         :param searchmoves: Restrict search to moves in this list.
         :param ponder: Bool to enable pondering mode. The engine will not stop
             pondering in the background until a *stop* command is received.
-        :param wtime: Integer of milliseconds white has left on the clock.
-        :param btime: Integer of milliseconds black has left on the clock.
+        :param wtime: Integer of milliseconds White has left on the clock.
+        :param btime: Integer of milliseconds Black has left on the clock.
         :param winc: Integer of white Fisher increment.
         :param binc: Integer of black Fisher increment.
         :param movestogo: Number of moves to the next time control. If this is
@@ -910,7 +910,7 @@ class Engine(object):
 
         :return: A tuple of two elements. The first is the best move according
             to the engine. The second is the ponder move. This is the reply
-            as sent by the engine. Either of the elements may be *None*.
+            as sent by the engine. Either of the elements may be ``None``.
 
         :raises: :exc:`~chess.uci.EngineStateException` if the engine is
             already calculating.
@@ -1030,7 +1030,7 @@ class Engine(object):
         """
         May be sent if the expected ponder move has been played.
 
-        The engine should continue searching but should switch from pondering
+        The engine should continue searching, but should switch from pondering
         to normal search.
 
         :return: Nothing.
@@ -1093,7 +1093,7 @@ class Engine(object):
         Terminate the engine.
 
         This is not an UCI command. It instead tries to terminate the engine
-        on operating system level, for example by sending SIGTERM on Unix
+        on operating system level, like sending SIGTERM on Unix
         systems. If possible, first try the *quit* command.
 
         :return: The return code of the engine process (or a Future).
@@ -1105,7 +1105,7 @@ class Engine(object):
         """
         Kill the engine.
 
-        Forcefully kill the engine process, for example by sending SIGKILL.
+        Forcefully kill the engine process, like by sending SIGKILL.
 
         :return: The return code of the engine process (or a Future).
         """
@@ -1132,7 +1132,7 @@ def popen_engine(command, engine_cls=Engine, setpgrp=False, _popen_lock=threadin
     'Tord Romstad, Marco Costalba and Joona Kiiski'
 
     :param setpgrp: Open the engine process in a new process group. This will
-        stop signals (such as keyboards interrupts) from propagating from the
+        stop signals (such as keyboard interrupts) from propagating from the
         parent process. Defaults to ``False``.
     """
     return _popen_engine(command, engine_cls, setpgrp, _popen_lock, **kwargs)
