@@ -18,11 +18,12 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
+import concurrent.futures
+import threading
+import random
+
 from chess.engine import EngineTerminatedException
 from chess.engine import EngineStateException
-from chess.engine import MockProcess
-from chess.engine import PopenProcess
-from chess.engine import SpurProcess
 from chess.engine import Option
 from chess.engine import OptionMap
 from chess.engine import LOGGER
@@ -32,15 +33,6 @@ from chess.engine import _spur_spawn_engine
 
 import chess
 
-import concurrent.futures
-import threading
-import random
-
-try:
-    import backport_collections as collections
-except ImportError:
-    import collections
-
 
 class PostHandler(object):
     """
@@ -81,21 +73,21 @@ class PostHandler(object):
         self.post = {}
         self.post["pv"] = {}
 
-    def depth(self, x):
+    def depth(self, depth):
         """Received depth in plies."""
-        self.post["depth"] = x
+        self.post["depth"] = depth
 
-    def score(self, x):
+    def score(self, score):
         """Receieved score in centipawns."""
-        self.post["score"] = x
+        self.post["score"] = score
 
-    def time(self, x):
+    def time(self, time):
         """Received new time searched in centiseconds."""
-        self.post["time"] = x
+        self.post["time"] = time
 
-    def nodes(self, x):
+    def nodes(self, nodes):
         """Received number of nodes searched."""
-        self.post["nodes"] = x
+        self.post["nodes"] = nodes
 
     def pv(self, moves):
         """Received the principal variation as a list of moves."""
@@ -128,7 +120,6 @@ class PostHandler(object):
         with self.lock:
             self.post.clear()
             self.post["pv"] = {}
-        pass
 
     def acquire(self, blocking=True):
         return self.lock.acquire(blocking)
@@ -145,37 +136,36 @@ class PostHandler(object):
 
 
 class FeatureMap(object):
-
     def __init__(self):
         # Populated with defaults to begin with
         self._features = {
-                "ping" : 0, # TODO: Remove dependency of xboard module on ping
-                "setboard" : 0,
-                "playother" : 0,
-                "san" : 0,
-                "usermove" : 0,
-                "time" : 1,
-                "draw" : 1,
-                "sigint" : 1,
-                "sigterm" : 1,
-                "reuse" : 1,
-                "analyze" : 1,
-                "myname" : None,
-                "variants" : None,
-                "colors" : 1,
-                "ics" : 0,
-                "name" : None,
-                "pause" : 0,
-                "nps" : 1,
-                "debug" : 0,
-                "memory" : 0,
-                "smp" : 0,
-                "egt" : 0,
-                "option" : OptionMap(),
-                "done" : None
-                }
+            "ping" : 0, # TODO: Remove dependency of xboard module on ping
+            "setboard" : 0,
+            "playother" : 0,
+            "san" : 0,
+            "usermove" : 0,
+            "time" : 1,
+            "draw" : 1,
+            "sigint" : 1,
+            "sigterm" : 1,
+            "reuse" : 1,
+            "analyze" : 1,
+            "myname" : None,
+            "variants" : None,
+            "colors" : 1,
+            "ics" : 0,
+            "name" : None,
+            "pause" : 0,
+            "nps" : 1,
+            "debug" : 0,
+            "memory" : 0,
+            "smp" : 0,
+            "egt" : 0,
+            "option" : OptionMap(),
+            "done" : None
+            }
 
-    def _set_feature(self, key, value):
+    def set_feature(self, key, value):
         try:
             value = int(value)
         except ValueError:
@@ -186,6 +176,18 @@ class FeatureMap(object):
         except KeyError:
             LOGGER.exception("exception looking up feature")
 
+    def get_option(self, key):
+        try:
+            return self._features["option"][key]
+        except KeyError:
+            LOGGER.exception("exception looking up option")
+
+    def set_option(self, key, value):
+        try:
+            self._features["option"][key] = value
+        except KeyError:
+            LOGGER.exception("exception looking up option")
+
     def get(self, key):
         try:
             return self._features[key]
@@ -298,17 +300,17 @@ class Engine(object):
                 min = int(params[3])
                 max = int(params[4])
             option = Option(name, type, default, min, max, var)
-            self.features._features["option"][option.name] = option
+            self.features.set_option(option.name, option)
             return
 
         features = features.split()
-        feature_map = [ feature.split("=") for feature in features ]
+        feature_map = [feature.split("=") for feature in features]
         for (key, value) in feature_map:
             value = value.strip("\"")
             if key == "variant":
-                self.features._set_feature(key, value.split(","))
+                self.features.set_feature(key, value.split(","))
             else:
-                self.features._set_feature(key, value)
+                self.features.set_feature(key, value)
 
     def _pong(self, pong_arg):
         try:
@@ -401,6 +403,24 @@ class Engine(object):
                 except concurrent.futures.TimeoutError:
                     pass
 
+    def _assert_supports_feature(self, feature_name):
+        if not self.features.supports(feature_name):
+            raise EngineStateException("engine does not support the '{}' feature", feature_name)
+
+    def _assert_not_busy(self, cmd):
+        with self.state_changed:
+            if not self.idle:
+                raise EngineStateException("{} command while engine is busy", cmd)
+
+    def command(self, msg):
+        def cmd():
+            with self.semaphore:
+                self.send_line(msg)
+
+                if self.terminated.is_set():
+                    raise EngineTerminatedException
+        return cmd
+
     def ping(self, async_callback=None):
         """
         Command used to synchronize with the engine.
@@ -431,30 +451,26 @@ class Engine(object):
 
         :return: Nothing
         """
-        def command():
-            with self.semaphore:
-                if ponder:
-                    self.send_line("hard")
-                else:
-                    self.send_line("easy")
-
-                if self.terminated.is_set():
-                    raise EngineTerminatedException()
+        if ponder:
+            msg = "hard"
+        else:
+            msg = "easy"
 
+        command = self.command(msg)
         return self._queue_command(command, async_callback)
 
     def easy(self, async_callback=None):
         """
         Tell the engine not to ponder.
         """
-        return self.pondering(False)
+        return self.pondering(False, async_callback)
 
     def hard(self, async_callback=None):
         """
         Tell the engine to ponder.
         TODO: pondering not yet supported.
         """
-        return self.pondering(True)
+        return self.pondering(True, async_callback)
 
     def set_post(self, flag, async_callback=None):
         """
@@ -464,16 +480,12 @@ class Engine(object):
 
         :return: Nothing
         """
-        def command():
-            with self.semaphore:
-                if flag == True:
-                    self.send_line("post")
-                else:
-                    self.send_line("nopost")
-
-                if self.terminated.is_set():
-                    raise EngineTerminatedException()
+        if flag:
+            msg = "post"
+        else:
+            msg = "nopost"
 
+        command = self.command(msg)
         return self._queue_command(command, async_callback)
 
     def post(self, async_callback=None):
@@ -482,7 +494,7 @@ class Engine(object):
 
         :return: Nothing
         """
-        return self.set_post(True)
+        return self.set_post(True, async_callback)
 
     def nopost(self, async_callback=None):
         """
@@ -490,7 +502,7 @@ class Engine(object):
 
         :return: Nothing
         """
-        return self.set_post(False)
+        return self.set_post(False, async_callback)
 
     def xboard(self, async_callback=None):
         """
@@ -511,6 +523,7 @@ class Engine(object):
                 if self.terminated.is_set():
                     raise EngineTerminatedException()
 
+            # TODO: Remove perhaps?
             self.post()
             self.easy()
             self.ping()
@@ -530,7 +543,7 @@ class Engine(object):
         for name, value in options.items():
             # Building string manually to avoid spaces
             option_string = "option " + name
-            option = self.features._features["option"][name]
+            option = self.features.get_option(name)
             has_value = option.type in \
                     ("spin", "check", "combo", "string")
             if has_value and value is not None:
@@ -566,17 +579,8 @@ class Engine(object):
 
         :return: Nothing
         """
-        with self.state_changed:
-            if not self.idle:
-                raise EngineStateException("new command while engine is busy")
-
-        def command():
-            with self.semaphore:
-                self.send_line("new")
-
-                if self.terminated.is_set():
-                    raise EngineTerminatedException()
-
+        self._assert_not_busy("new")
+        command = self.command("new")
         return self._queue_command(command, async_callback)
 
     def setboard(self, board, async_callback=None):
@@ -590,9 +594,7 @@ class Engine(object):
         :raises: :exc:`~chess.engine.EngineStateException` if the engine is still
             calculating.
         """
-        with self.state_changed:
-            if not self.idle:
-                raise EngineStateException("setboard command while engine is busy")
+        self._assert_not_busy("setboard")
 
         # Setboard should be sent after force.
         self.force()
@@ -603,13 +605,37 @@ class Engine(object):
 
         self.board = board.copy(stack=False)
 
-        def command():
-            with self.semaphore:
-                self.send_line(" ".join(builder))
+        command = self.command(" ".join(builder))
+        return self._queue_command(command, async_callback)
 
-                if self.terminated.is_set():
-                    raise EngineTerminatedException()
+    def undo(self, async_callback=None):
+        """
+        Puts the engine in force mode and takes back one move.
 
+        :return: Nothing
+        """
+        self._assert_not_busy("undo")
+
+        # Undo should be sent after force.
+        self.force()
+
+        self.board.pop()
+
+        command = self.command("undo")
+        return self._queue_command(command, async_callback)
+
+    def remove(self, async_callback=None):
+        """
+        Tells the engine to retract two moves (one from each side).
+
+        :return: Nothing
+        """
+        self._assert_not_busy("remove")
+
+        self.board.pop()
+        self.board.pop()
+
+        command = self.command("remove")
         return self._queue_command(command, async_callback)
 
     def memory(self, amount, async_callback=None):
@@ -620,20 +646,10 @@ class Engine(object):
 
         :return: Nothing
         """
-        if not self.features.supports("memory"):
-            raise EngineStateException("engine does not support the 'memory' feature")
-
-        with self.state_changed:
-            if not self.idle:
-                raise EngineStateException("memory command while engine is busy")
-
-        def command():
-            with self.semaphore:
-                self.send_line("memory " + str(amount))
-
-                if self.terminated.is_set():
-                    raise EngineTerminatedException
+        self._assert_supports_feature("memory")
+        self._assert_not_busy("memory")
 
+        command = self.command("memory " + str(amount))
         return self._queue_command(command, async_callback)
 
     def cores(self, num, async_callback=None):
@@ -645,20 +661,10 @@ class Engine(object):
 
         :return: Nothing
         """
-        if not self.features.supports("smp"):
-            raise EngineStateException("engine does not support the 'smp' feature")
-
-        with self.state_changed:
-            if not self.idle:
-                raise EngineStateException("cores command while engine is busy")
-
-        def command():
-            with self.semaphore:
-                self.send_line("cores " + str(num))
-
-                if self.terminated.is_set():
-                    raise EngineTerminatedException
+        self._assert_supports_feature("smp")
+        self._assert_not_busy("cores")
 
+        command = self.command("cores " + str(num))
         return self._queue_command(command, async_callback)
 
     def playother(self, async_callback=None):
@@ -667,21 +673,76 @@ class Engine(object):
 
         :return: Nothing
         """
-        if not self.features.supports("playother"):
-            raise EngineStateException("engine does not support the 'playother' feature")
-
-        with self.state_changed:
-            if not self.idle:
-                raise EngineStateException("playother command while engine is busy")
+        self._assert_supports_feature("playother")
+        self._assert_not_busy("playother")
 
         self.in_force = False
-        def command():
-            with self.semaphore:
-                self.send_line("playother")
+        command = self.command("playother")
+        return self._queue_command(command, async_callback)
 
-                if self.terminated.is_set():
-                    raise EngineTerminatedException
+    def set_side_to_move(self, color, async_callback=None):
+        """
+        Set the side to move, set the engine to move for the opposite side
+        and exit force mode.
 
+        :param color: The desired side to move.
+
+        :return: Nothing
+        """
+        self._assert_supports_feature("colors")
+        side = chess.COLOR_NAMES[color]
+        self._assert_not_busy(side)
+
+        self.in_force = False
+        command = self.command(side)
+        return self._queue_command(command, async_callback)
+
+    def white(self, async_callback=None):
+        """
+        Set the side to move to be white, engine to play as black and
+        exit force mode.
+
+        :return: Nothing
+        """
+        self.set_side_to_move(chess.WHITE, async_callback)
+
+    def black(self, async_callback=None):
+        """
+        Set the side to move to be black, engine to play as white and
+        exit force mode.
+
+        :return: Nothing
+        """
+        self.set_side_to_move(chess.BLACK, async_callback)
+
+    def random(self, async_callback=None):
+        """
+        Toggles random mode.
+
+        In random mode, the engine may choose to add a random factor to it's
+        evaluation of any given position prompting variation in play or may
+        ignore it entirely.
+
+        :return: Nothing
+        """
+        self._assert_not_busy("random")
+
+        command = self.command("random")
+        return self._queue_command(command, async_callback)
+
+    def nps(self, target_nps, async_callback=None):
+        """
+        Tell the engine to limit it's speed of search in terms of
+        Nodes Per Second to the provided value.
+
+        :param target_nps: The limiting Nodes Per Second value
+
+        :return: Nothing
+        """
+        self._assert_supports_feature("nps")
+        self._assert_not_busy("nps")
+
+        command = self.command("nps " + str(target_nps))
         return self._queue_command(command, async_callback)
 
     def st(self, time, async_callback=None):
@@ -692,17 +753,9 @@ class Engine(object):
 
         :return: Nothing
         """
-        with self.state_changed:
-            if not self.idle:
-                raise EngineStateException("st command while engine is busy")
-
-        def command():
-            with self.semaphore:
-                self.send_line("st " + str(time))
-
-                if self.terminated.is_set():
-                    raise EngineTerminatedException
+        self._assert_not_busy("st")
 
+        command = self.command("st " + str(time))
         return self._queue_command(command, async_callback)
 
     def sd(self, depth, async_callback=None):
@@ -713,17 +766,9 @@ class Engine(object):
 
         :return: Nothing
         """
-        with self.state_changed:
-            if not self.idle:
-                raise EngineStateException("sd command while engine is busy")
-
-        def command():
-            with self.semaphore:
-                self.send_line("sd " + str(depth))
-
-                if self.terminated.is_set():
-                    raise EngineTerminatedException
+        self._assert_not_busy("sd")
 
+        command = self.command("sd " + str(depth))
         return self._queue_command(command, async_callback)
 
     def time(self, time, async_callback=None):
@@ -734,22 +779,25 @@ class Engine(object):
 
         :return: Nothing
         """
-        if not self.features.supports("time"):
-            raise EngineStateException("engine does not support the 'time' feature")
-
-        with self.state_changed:
-            if not self.idle:
-                raise EngineStateException("time command while engine is busy")
-
-        def command():
-            with self.semaphore:
-                self.send_line("time " + str(time))
-
-                if self.terminated.is_set():
-                    raise EngineTerminatedException
+        self._assert_supports_feature("time")
+        self._assert_not_busy("time")
 
+        command = self.command("time " + str(time))
         return self._queue_command(command, async_callback)
 
+    def otim(self, time, async_callback=None):
+        """
+        Synchronize the engines clock with the total amount of time left.
+
+        :param time: The total time left in centiseconds
+
+        :return: Nothing
+        """
+        self._assert_supports_feature("time")
+        self._assert_not_busy("otim")
+
+        command = self.command("otim " + str(time))
+        return self._queue_command(command, async_callback)
 
     def level(self, movestogo=0, minutes=5, seconds=None, inc=0, async_callback=None):
         """
@@ -770,28 +818,20 @@ class Engine(object):
 
         :return: Nothing
         """
-        with self.state_changed:
-            if not self.idle:
-                raise EngineStateException("level command while engine is busy")
+        self._assert_not_busy("level")
 
         builder = []
         builder.append("level")
         builder.append(str(int(movestogo)))
-        builder.append(str(int(minutes)))
 
         if seconds is not None:
-            builder.append(":")
-            builder.append(str(int(seconds)))
+            builder.append(str(int(minutes)) + ":" + str(int(seconds)))
+        else:
+            builder.append(str(int(minutes)))
 
         builder.append(str(int(inc)))
 
-        def command():
-            with self.semaphore:
-                self.send_line(" ".join(builder))
-
-                if self.terminated.is_set():
-                    raise EngineTerminatedException
-
+        command = self.command(" ".join(builder))
         return self._queue_command(command, async_callback)
 
     def set_auto_force(self, flag):
@@ -815,13 +855,7 @@ class Engine(object):
         :return: Nothing
         """
         self.in_force = True
-        def command():
-            with self.semaphore:
-                self.send_line("force")
-
-                if self.terminated.is_set():
-                    raise EngineTerminatedException
-
+        command = self.command("force")
         return self._queue_command(command, async_callback)
 
     def go(self, async_callback=None):
@@ -834,10 +868,9 @@ class Engine(object):
         :raises: :exc:`~chess.engine.EngineStateException` if the engine is
             already calculating.
         """
-        with self.state_changed:
-            if not self.idle:
-                raise EngineStateException("go command while engine is already busy")
+        self._assert_not_busy("go")
 
+        with self.state_changed:
             self.idle = False
             self.search_started.clear()
             self.move_received.clear()
